#!/usr/bin/env node
"use strict";

var _updateNotifier = _interopRequireDefault(require("update-notifier"));

var _logSymbols = _interopRequireDefault(require("log-symbols"));

var _path = _interopRequireDefault(require("path"));

var _debug = _interopRequireDefault(require("debug"));

var _inquirer = require("./inquirer");

var _package = _interopRequireWildcard(require("../package.json"));

var _verifyToken = require("./verify-token");

var _viewReleases = require("./view-releases");

var _publishRelease = require("./publish-release");

var _prepareRelease = require("./prepare-release");

var _bulkMergePrs = require("./bulk-merge-prs");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debug = (0, _debug.default)(`${_package.name}:${_path.default.basename(__filename)}`);
(0, _updateNotifier.default)({
  pkg: _package.default
}).notify();

(async () => {
  try {
    (0, _verifyToken.verifyToken)();
    const org = await (0, _inquirer.askOrg)();
    const orgAction = await (0, _inquirer.askOrgAction)();

    if (orgAction === 'releases') {
      const repo = await (0, _inquirer.askRepo)(org);
      const action = await (0, _inquirer.askRepoAction)({
        org,
        repo
      });

      if (action === 'prepare-release') {
        await (0, _prepareRelease.prepareRelease)({
          org,
          repo
        });
      }

      if (action === 'publish-release') {
        await (0, _publishRelease.publishRelease)({
          org,
          repo
        });
      }
    }

    if (orgAction === 'bulk-merge-renovate-prs') {
      await (0, _bulkMergePrs.bulkMergePRs)(org);
    }

    if (orgAction === 'view-releases') {
      const format = await (0, _inquirer.askFormatOutput)();
      await (0, _viewReleases.viewReleases)({
        org,
        format
      });
    }
  } catch (error) {
    debug(error);
    console.log(_logSymbols.default.error, error.message);
    console.log(_logSymbols.default.info, `
    For debug logs run again with DEBUG env var:

    DEBUG=gh-shipit:* gh-shipit
    `.trim());
  }

  process.exit(0);
})();