"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLastDevelopCommitSHA = getLastDevelopCommitSHA;
exports.createReleaseBranch = createReleaseBranch;
exports.createReleaseNotes = createReleaseNotes;
exports.createReleasePR = createReleasePR;

var _restClient = require("@shelf/gh-sdk/lib/rest-client");

var _ghSdk = require("@shelf/gh-sdk");

async function getLastDevelopCommitSHA({
  org,
  repo
}) {
  return (0, _ghSdk.getLatestDevelopCommitSHA)({
    owner: org,
    repo
  });
}

async function createReleaseBranch({
  org,
  repo,
  version,
  commitHash
}) {
  return (0, _ghSdk.createReleaseBranch)({
    owner: org,
    sha: commitHash,
    repo,
    version
  });
}

async function createReleaseNotes({
  org,
  repo,
  version,
  releaseTitle
}) {
  const gh = (0, _restClient.getClient)();
  const tagName = `v${version}`;
  const {
    data
  } = await gh.repos.createRelease({
    owner: org,
    repo,
    tag_name: tagName,
    target_commitish: `release/${tagName}`,
    name: `Release ${tagName}: ${releaseTitle}`,
    draft: true
  });
  return data;
}

async function createReleasePR({
  org,
  repo,
  version,
  releaseTitle
}) {
  return (0, _ghSdk.createReleasePR)({
    owner: org,
    repo,
    version,
    releaseTitle
  });
}