"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getBranchDiff = getBranchDiff;

var _lodash = _interopRequireDefault(require("lodash"));

var _semver = _interopRequireDefault(require("semver"));

var _path = _interopRequireDefault(require("path"));

var _clientReleases = require("./client-releases");

var _clientRepos = require("./client-repos");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debug = require('debug')(`${require('../package').name}:${_path.default.basename(__filename)}`);

async function getBranchDiff({
  org,
  repo
}) {
  try {
    const [{
      status,
      ahead_by,
      behind_by,
      commits,
      base_commit
    }, lastRelease, lastDraftReleaseTag] = await Promise.all([(0, _clientRepos.compareBranches)({
      org,
      repo
    }), (0, _clientReleases.getLastRelease)({
      org,
      repo
    }), (0, _clientReleases.getLastDraftReleaseTag)({
      org,
      repo
    })]);

    const lastHeadCommitDate = _lodash.default.get(commits.reverse(), '[0].commit.author.date', '');

    const lastBaseCommitDate = _lodash.default.get(base_commit, 'commit.author.date', '');

    const lastCommitDate = lastHeadCommitDate || lastBaseCommitDate;
    const repoDiff = {
      org,
      repo,
      status,
      ahead_by,
      behind_by,
      lastCommitDate,
      lastRelease: _semver.default.clean(lastRelease),
      lastDraftReleaseTag: lastDraftReleaseTag || '-'
    };
    debug('%o', repoDiff);
    return repoDiff;
  } catch (error) {
    if (error.code === 404) {
      debug('repo %s, no master or develop branch', repo);
    }

    return {
      org,
      repo,
      status: 'no-branch'
    };
  }
}